@@ -5,7 +5,7 @@ use Carp 'croak';
 use Errno 'EEXIST';
 use Fcntl qw(O_CREAT O_EXCL O_RDWR);
 use File::Copy 'move';
-use File::Spec;
+use File::Spec::Functions 'catfile';
 use IO::File;
 use Mojo::Util 'md5_sum';
 
@@ -22,7 +22,7 @@ has handle => sub {
   }
 
   # Open new or temporary file
-  my $base = File::Spec->catfile($self->tmpdir, 'mojo.tmp');
+  my $base = catfile File::Spec::Functions::tmpdir, 'mojo.tmp';
   my $name = $path // $base;
   until ($handle->open($name, O_CREAT | O_EXCL | O_RDWR)) {
     croak qq{Can't open file "$name": $!} if defined $path || $! != $!{EEXIST};
@@ -35,7 +35,7 @@ has handle => sub {
 
   return $handle;
 };
-has tmpdir => sub { $ENV{MOJO_TMPDIR} || File::Spec->tmpdir };
+has tmpdir => sub { $ENV{MOJO_TMPDIR} || File::Spec::Functions::tmpdir };
 
 sub DESTROY {
   my $self = shift;
@@ -223,7 +223,7 @@ Check if asset contains a specific string.
 
 =head2 get_chunk
 
-  my $chunk = $file->get_chunk($start);
+  my $bytes = $file->get_chunk($start);
 
 Get chunk of data starting from a specific position.
 
@@ -247,7 +247,7 @@ Size of asset data in bytes.
 
 =head2 slurp
 
-  my $string = $file->slurp;
+  my $bytes = $file->slurp;
 
 Read all asset data at once.
 
