@@ -147,7 +147,7 @@ Clone content if possible, otherwise return C<undef>.
 
 =head2 get_body_chunk
 
-  my $chunk = $single->get_body_chunk(0);
+  my $bytes = $single->get_body_chunk(0);
 
 Get a chunk of content starting from a specfic position.
 
